/* ===========================================================
 * nb.js
 * Norwegian Bokmål translation for Trumbowyg
 * http://alex-d.github.com/Trumbowyg
 * ===========================================================
 * Author : Jon Severin Eivik Jakobsen
 *          Github : https://github.com/jsejakobsen
 *
 * Mod by:  Gunnar Tjomlid
 *          Github : https://github.com/civix74
 *          Twitter : @civix
 *          Website : https://about.me/civix
 */

// jshint camelcase:false
jQuery.trumbowyg.langs.nb = {
    viewHTML: 'Vis HTML',

    undo: 'Angre',
    redo: 'Gjør om',

    formatting: 'Formater',
    p: 'Avsnitt',
    blockquote: 'Sitat',
    code: 'Kode',
    header: 'Overskrift',

    bold: 'Fet',
    italic: 'Kursiv',
    strikethrough: 'Gjennomstreking',
    underline: 'Understreking',

    strong: 'Uthevet',
    em: 'Kursiv',
    del: 'Slettet',

    superscript: 'Hevet',
    subscript: 'Senket',

    unorderedList: 'Punktliste',
    orderedList: 'Nummerert liste',

    insertImage: 'Sett inn bilde',
    insertVideo: 'Sett inn video',
    link: 'Lenke',
    createLink: 'Sett inn lenke',
    unlink: 'Fjern lenke',

    justifyLeft: 'Venstrejuster',
    justifyCenter: 'Midtstill',
    justifyRight: 'Høyrejuster',
    justifyFull: 'Blokkjuster',

    horizontalRule: 'Horisontal linje',
    removeformat: 'Fjern formatering',

    fullscreen: 'Fullskjerm',

    close: 'Lukk',

    submit: 'Bekreft',
    reset: 'Avbryt',

    required: 'Påkrevd',
    description: 'Beskrivelse',
    title: 'Tittel',
    text: 'Tekst',
    target: 'Mål',
    width: 'Bredde'
};
