/**
 * Trumbowyg v2.31.0 - A lightweight WYSIWYG editor
 * Trumbowyg plugin stylesheet
 * ------------------------
 * @link https://alex-d.github.io/Trumbowyg/
 * @license MIT
 * @author Alexandre Demode (Alex-D)
 *         Twitter : @AlexandreDemode
 *         Website : alex-d.fr
 */

.trumbowyg-giphy-button svg {
  -webkit-transform: scale(1.22);
          transform: scale(1.22);
}

.trumbowyg-giphy-search {
  display: block;
  width: 80%;
  margin: 5%;
  padding-left: 10px;
  padding-right: 150px;
}

.trumbowyg-giphy-close {
  position: absolute;
  top: calc(5% + 8px);
  right: calc(5% - 2px);
  width: 30px;
  height: 30px;
  background: none;
  border: 1px solid transparent;
}
.trumbowyg-giphy-close:hover, .trumbowyg-giphy-close:focus {
  outline: none;
  background: #ecf0f1;
}
.trumbowyg-giphy-close:focus {
  border-color: rgba(0, 0, 0, 0.3);
}

.trumbowyg-powered-by-giphy {
  position: absolute;
  top: calc(5% + 12px);
  right: calc(15% + 10px);
  pointer-events: none;
  -webkit-user-select: none;
     -moz-user-select: none;
      -ms-user-select: none;
          user-select: none;
}
.trumbowyg-powered-by-giphy span {
  text-transform: uppercase;
  font-weight: bold;
  font-size: 10px;
  opacity: 0.6;
}
.trumbowyg-powered-by-giphy svg {
  width: 66px;
  height: 15px;
  vertical-align: middle;
  margin-left: 6px;
  opacity: 0.45;
}

.trumbowyg-giphy-modal-scroll {
  overflow: auto;
  overflow-x: hidden;
  height: 240px;
}

.trumbowyg-giphy-modal {
  padding: 0 5%;
  -webkit-columns: 3;
     -moz-columns: 3;
          columns: 3;
  -webkit-column-gap: 10px;
     -moz-column-gap: 10px;
          column-gap: 10px;
}
.trumbowyg-giphy-modal .trumbowyg-giphy-no-result {
  width: 250%;
  margin: 13% 0 0 29%;
}
.trumbowyg-giphy-modal .trumbowyg-giphy-offline {
  font-size: 18px;
  width: 305%;
  height: 600px;
  margin-top: 95px;
  text-align: center;
}

.trumbowyg-giphy-modal .img-container {
  width: 100%;
  margin-bottom: 10px;
  background-color: #ecf0f1;
}
.trumbowyg-giphy-modal .img-container img {
  width: 100%;
  cursor: pointer;
  opacity: 0;
  -webkit-transition: opacity 150ms;
  transition: opacity 150ms;
}
.trumbowyg-giphy-modal .img-container img:hover, .trumbowyg-giphy-modal .img-container img:focus {
  border: #2ecc71 solid 3px;
}
.trumbowyg-giphy-modal .img-container img.tbw-loaded {
  opacity: 1;
}