/**
 * Trumbowyg v2.31.0 - A lightweight WYSIWYG editor
 * Trumbowyg plugin stylesheet
 * ------------------------
 * @link https://alex-d.github.io/Trumbowyg/
 * @license MIT
 * @author Alexandre Demode (Alex-D)
 *         Twitter : @AlexandreDemode
 *         Website : alex-d.fr
 */

.trumbowyg-dropdown-table {
  max-height: unset;
}
.trumbowyg-dropdown-table table {
  all: unset;
  display: inline-block;
  margin: 10px;
  border-collapse: collapse;
}
.trumbowyg-dropdown-table table td {
  all: unset;
  position: relative;
  display: table-cell;
  height: 20px;
  width: 20px;
  cursor: pointer;
  background: #fff;
}
.trumbowyg-dropdown-table table td::after {
  content: "";
  display: block;
  position: absolute;
  top: 1px;
  right: 1px;
  bottom: 1px;
  left: 1px;
  border: 1px solid #cecece;
  pointer-events: none;
}
.trumbowyg-dropdown-table table td.active::after {
  background-color: #000;
  border-color: #000;
}
.trumbowyg-dropdown-table .trumbowyg-table-size {
  text-align: center;
}

.trumbowyg-table-dropdown-title {
  padding: 8px 10px;
  font-size: 12px;
  text-transform: uppercase;
  letter-spacing: 2px;
  font-weight: bold;
}

.trumbowyg-dropdown-button-group + .trumbowyg-table-dropdown-title {
  margin-top: 24px;
}

.trumbowyg-table-cell-selection-mode ::-moz-selection {
  color: inherit;
  background-color: transparent;
}

.trumbowyg-table-cell-selection-mode ::selection {
  color: inherit;
  background-color: transparent;
}

.trumbowyg-table-cell-selected {
  background-color: #b4d3fe !important;
}

.trumbowyg-table-resize-layers {
  position: absolute;
  top: 0;
  left: 0;
  width: 0;
  height: 0;
}

.trumbowyg-table-resize-vertical-handle {
  position: absolute;
  width: 5px;
  margin-left: -3px;
  cursor: col-resize;
}

.trumbowyg-table-resize-vertical-handle::after {
  content: "";
  position: absolute;
  top: 0;
  left: 1px;
  width: 3px;
  height: 100%;
  background: #0073ff;
  border-radius: 3px;
  pointer-events: none;
  opacity: 0;
}

.trumbowyg-table-resize-vertical-handle:hover::after {
  opacity: 1;
}

.trumbowyg-dropdown-tableCellBackgroundColor:not(.trumbowyg-dropdown--color-list),
.trumbowyg-dropdown-tableBorderColor:not(.trumbowyg-dropdown--color-list) {
  max-width: 276px;
  padding: 7px 5px;
  overflow: initial;
}
.trumbowyg-dropdown-tableCellBackgroundColor:not(.trumbowyg-dropdown--color-list) button,
.trumbowyg-dropdown-tableBorderColor:not(.trumbowyg-dropdown--color-list) button {
  display: block;
  position: relative;
  float: left;
  text-indent: -9999px;
  height: 20px;
  width: 20px;
  border: 1px solid #333;
  padding: 0;
  margin: 2px;
}
.trumbowyg-dropdown-tableCellBackgroundColor:not(.trumbowyg-dropdown--color-list) button:hover::after, .trumbowyg-dropdown-tableCellBackgroundColor:not(.trumbowyg-dropdown--color-list) button:focus::after,
.trumbowyg-dropdown-tableBorderColor:not(.trumbowyg-dropdown--color-list) button:hover::after,
.trumbowyg-dropdown-tableBorderColor:not(.trumbowyg-dropdown--color-list) button:focus::after {
  content: " ";
  display: block;
  position: absolute;
  top: -5px;
  left: -5px;
  width: 27px;
  height: 27px;
  background: inherit;
  border: 1px solid #fff;
  -webkit-box-shadow: #000 0 0 2px;
          box-shadow: #000 0 0 2px;
  z-index: 10;
}

.trumbowyg-dropdown-tableCellBackgroundColor.trumbowyg-dropdown--color-list button:not(.trumbowyg-removeTableCellBackgroundColor-dropdown-button):not(.trumbowyg-removeTableBorderColor-dropdown-button),
.trumbowyg-dropdown-tableBorderColor.trumbowyg-dropdown--color-list button:not(.trumbowyg-removeTableCellBackgroundColor-dropdown-button):not(.trumbowyg-removeTableBorderColor-dropdown-button) {
  position: relative;
  color: #fff !important;
}
.trumbowyg-dropdown-tableCellBackgroundColor.trumbowyg-dropdown--color-list button:not(.trumbowyg-removeTableCellBackgroundColor-dropdown-button):not(.trumbowyg-removeTableBorderColor-dropdown-button):hover::after, .trumbowyg-dropdown-tableCellBackgroundColor.trumbowyg-dropdown--color-list button:not(.trumbowyg-removeTableCellBackgroundColor-dropdown-button):not(.trumbowyg-removeTableBorderColor-dropdown-button):focus::after,
.trumbowyg-dropdown-tableBorderColor.trumbowyg-dropdown--color-list button:not(.trumbowyg-removeTableCellBackgroundColor-dropdown-button):not(.trumbowyg-removeTableBorderColor-dropdown-button):hover::after,
.trumbowyg-dropdown-tableBorderColor.trumbowyg-dropdown--color-list button:not(.trumbowyg-removeTableCellBackgroundColor-dropdown-button):not(.trumbowyg-removeTableBorderColor-dropdown-button):focus::after {
  content: " ";
  display: block;
  position: absolute;
  top: 13px;
  left: 0;
  width: 0;
  height: 0;
  border: 5px solid transparent;
  border-left-color: #fff;
}