/* ===========================================================
 * mn.js
 * Mongolian translation for Trumbowyg
 * http://alex-d.github.com/Trumbowyg
 * ===========================================================
 * Author : Ganbayar.B (ganbayar13)
 */

jQuery.trumbowyg.langs.mn = {
    viewHTML: 'HTML харах',
    undo: 'Буцаах',
    redo: 'Дахих',
    formatting: 'Формат',
    p: 'Догол мөр',
    blockquote: 'Ишлэл',
    code: 'Код',
    header: 'Гарчиг',
    bold: 'Тод',
    italic: 'Налуу',
    strikethrough: 'Дундуур зураас',
    underline: 'Доогуур зураас',
    strong: 'Тод',
    em: 'Налуу',
    del: 'Дундуур зураас',
    superscript: 'Дээд индекс',
    subscript: 'Доод индекс',
    unorderedList: 'Дугаарлаагүй жагсаалт',
    orderedList: 'Дугаарласан жагсаалт',
    insertImage: 'Зураг оруулах',
    insertVideo: 'Видео оруулах',
    link: 'Холбоос',
    createLink: 'Холбоос үүсгэх',
    unlink: 'Холбоос цуцлах',
    justifyLeft: 'Зүүн тийш шахах',
    justifyCenter: 'Голлуулах',
    justifyRight: 'Баруун Баруун тийш шахах',
    justifyFull: 'Тэгшитгэх',
    horizontalRule: 'Хөндлөн шугам',
    removeformat: 'Формат арилгах',
    fullscreen: 'Дэлгэц дүүргэх',
    close: 'Хаах',
    submit: 'Оруулах',
    reset: 'Цуцлах',
    required: 'Шаардлагатай',
    description: 'Тайлбар',
    title: 'Гарчиг',
    text: 'Текст',
    target: 'Бай'
};
