/* ===========================================================
 * az.js
 * Azerbaijani translation for Trumbowyg
 * http://alex-d.github.com/Trumbowyg
 * ===========================================================
 * Author : Qalib Qurbanov
 *          Github : https://github.com/qalibqurbanov
 */

jQuery.trumbowyg.langs.az = {
    viewHTML: 'HTML Kodu',

    formatting: 'Formatlama',
    p: 'Abzas',
    blockquote: 'Sitat',
    code: 'Kod',
    header: 'Başlıq',

    undo: 'Geri al',
    redo: 'İrəli al',

    superscript: 'Sözüstü',
    subscript: 'Sözaltı',

    bold: 'Qalın',
    italic: 'İtalik',
    strikethrough: 'Üzeri xəttli',
    underline: 'Altı xəttli',

    strong: 'Qalın',
    em: 'Vurğulu',
    del: 'Üzəri xəttli',

    unorderedList: 'İşarələnmiş siyahı',
    orderedList: 'Nömrələnmiş siyahı',

    insertImage: 'Şəkil yerləşdir',
    insertVideo: 'Video yerləşdir',
    link: 'Link',
    createLink: 'Link yerləşdir',
    unlink: 'Linki sil',

    justifyLeft: 'Sola nizamla',
    justifyCenter: 'Ortaya nizamla',
    justifyRight: 'Sağa nizamla',
    justifyFull: 'Üfüqi nizamla',

    horizontalRule: 'Üfüqi xətt əlavə et',

    fullscreen: 'Tam ekran',

    close: 'Bağla',

    submit: 'Təsdiq et',
    reset: 'Sıfırla',

    required: 'Vacib',
    description: 'Açıqlama',
    title: 'Başlıq',
    text: 'Mətn',

    removeformat: 'Formatlamanı təmizlə'
};
