/**
 * Trumbowyg v2.31.0 - A lightweight WYSIWYG editor
 * Trumbowyg plugin stylesheet
 * ------------------------
 * @link https://alex-d.github.io/Trumbowyg/
 * @license MIT
 * @author Alexandre Demode (Alex-D)
 *         Twitter : @AlexandreDemode
 *         Website : alex-d.fr
 */

.trumbowyg-highlight-form-group {
    margin: 15px 10px;

    .trumbowyg-highlight-form-control {
        width: 100%;
        border: 1px solid #DEDEDE;
        font-size: 14px;
        padding: 7px;

        &.code {
            height: 200px;
        }
    }
}
